==> digiclockwdg_0.3.1-1.tar.gz: digiclockwdg-0.3.1/digiclock_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <location filename="digitalclockwdg.cpp" line="15"/>
        <source>Digital Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Digital Clock settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="32"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="55"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="88"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="98"/>
        <source>Default (LCD)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="118"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="136"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="143"/>
        <source>Digits Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="155"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="174"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="182"/>
        <source>24H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="187"/>
        <source>12H (AM/PM)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="192"/>
        <source>Military</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="200"/>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="207"/>
        <source>Blinking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="218"/>
        <source>Time Zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="232"/>
        <source>Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="261"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="268"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="188"/>
        <source>DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="189"/>
        <source>Developed with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="190"/>
        <source>Desktop widget, showing digital time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="191"/>
        <source>Send reports to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="198"/>
        <source>About DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> digiclockwdg_0.4.0.tar.gz: digiclockwdg-0.4.0/digiclock_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>24H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Military</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Clock app on Click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate on Accel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developed with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Desktop widget, showing digital time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send reports to:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
